@@ -41,7 +41,7 @@ class Wallet:
 
     def validate(self):
         key = self.__read_key()
-        account = self._web3.eth.account.privateKeyToAccount(key)
+        account = self._web3.eth.account.from_key(key)
         return account.address == self._address
 
     @staticmethod
@@ -59,7 +59,7 @@ class Wallet:
 
     def sign_tx(self, tx):
         private_key = self.__read_key()
-        account = self._web3.eth.account.privateKeyToAccount(private_key)
+        account = self._web3.eth.account.from_key(private_key)
         nonce = Wallet._get_nonce(self._web3, account.address)
         logger.debug(f'`Wallet` signing tx: sender address: {account.address} nonce: {nonce}, '
                      f'gasprice: {self._web3.eth.gasPrice}')
@@ -67,11 +67,11 @@ class Wallet:
         gas_price = max(gas_price, self.MIN_GAS_PRICE)
         tx['nonce'] = nonce
         tx['gasPrice'] = gas_price
-        signed_tx = self._web3.eth.account.signTransaction(tx, private_key)
+        signed_tx = self._web3.eth.account.sign_transaction(tx, private_key)
         logger.debug(f'`Wallet` signed tx is {signed_tx}')
         return signed_tx.rawTransaction
 
     def sign(self, msg_hash):
         private_key = self.__read_key()
-        account = self._web3.eth.account.privateKeyToAccount(private_key)
+        account = self._web3.eth.account.from_key(private_key)
         return account.signHash(msg_hash)
